Module commands

Module commands 

High-level package manager commands (add, remove, tree, etc.).

Constants

LOCKFILE
The default lockfile name.
MANIFEST_FILE
The default manifest file name.

Functions

add
Add a dependency to the manifest.
find_manifest
Find the manifest file in the given directory or its ancestors.
init
Initialize a new package manifest in the given directory.
remove
Remove a dependency from the manifest.
resolve_and_lock
Resolve dependencies and generate/update the lockfile.
show_tree
Display the dependency tree.