High-level package manager commands (add, remove, tree, etc.).
Constants
- LOCKFILE
- The default lockfile name.
- MANIFEST_
FILE - The default manifest file name.
Functions
- add
- Add a dependency to the manifest.
- find_
manifest - Find the manifest file in the given directory or its ancestors.
- init
- Initialize a new package manifest in the given directory.
- remove
- Remove a dependency from the manifest.
- resolve_
and_ lock - Resolve dependencies and generate/update the lockfile.
- show_
tree - Display the dependency tree.